@@ -35,7 +35,7 @@
 #include <Akonadi/Calendar/IncidenceChanger>
 
 #include <KCalUtils/IncidenceFormatter>
-#include <KCalCore/Visitor>
+#include <KCalendarCore/Visitor>
 
 #include <KConfig>
 #include <KConfigGroup>
@@ -48,7 +48,7 @@
 #include <QLocale>
 
 using namespace EventViews;
-using namespace KCalCore;
+using namespace KCalendarCore;
 using namespace KCalUtils;
 
 enum {
@@ -76,13 +76,15 @@ class ListViewItem : public QTreeWidgetItem
 {
 public:
     ListViewItem(const Akonadi::Item &incidence, QTreeWidget *parent)
-        : QTreeWidgetItem(parent), mTreeWidget(parent), mIncidence(incidence)
+        : QTreeWidgetItem(parent)
+        , mTreeWidget(parent)
+        , mIncidence(incidence)
     {
     }
 
     bool operator<(const QTreeWidgetItem &other) const override;
 
-    const QTreeWidget *mTreeWidget;
+    const QTreeWidget *mTreeWidget = nullptr;
     const Akonadi::Item mIncidence;
     QDateTime start;
     QDateTime end;
@@ -93,21 +95,20 @@ bool ListViewItem::operator<(const QTreeWidgetItem &other) const
     const ListViewItem *otheritem = static_cast<const ListViewItem *>(&other);
 
     switch (treeWidget()->sortColumn()) {
-
-    case StartDateTime_Column: {
+    case StartDateTime_Column:
         return otheritem->start < start;
-    }
-    case EndDateTime_Column: {
+    case EndDateTime_Column:
+    {
         Incidence::Ptr thisInc = CalendarSupport::incidence(mIncidence);
-        const auto thisEnd = thisInc->dateTime(Incidence::RoleEnd).toLocalZone().dateTime();
+        const auto thisEnd = thisInc->dateTime(Incidence::RoleEnd).toLocalTime();
 
         Incidence::Ptr otherInc = CalendarSupport::incidence(otheritem->mIncidence);
-        const auto otherEnd = otherInc->dateTime(Incidence::RoleEnd).toLocalZone().dateTime();
+        const auto otherEnd = otherInc->dateTime(Incidence::RoleEnd).toLocalTime();
 
         return otherEnd < thisEnd;
     }
     default:
-        return QTreeWidgetItem::operator < (other);
+        return QTreeWidgetItem::operator <(other);
     }
 }
 
@@ -122,16 +123,13 @@ public:
     {
     }
 
-    void addIncidences(const Akonadi::ETMCalendar::Ptr &calendar,
-                       const KCalCore::Incidence::List &incidenceList, const QDate &date);
-    void addIncidence(const Akonadi::ETMCalendar::Ptr &calendar,
-                      const KCalCore::Incidence::Ptr &, const QDate &date);
-    void addIncidence(const Akonadi::ETMCalendar::Ptr &calendar,
-                      const Akonadi::Item &, const QDate &date);
+    void addIncidences(const Akonadi::ETMCalendar::Ptr &calendar, const KCalendarCore::Incidence::List &incidenceList, const QDate &date);
+    void addIncidence(const Akonadi::ETMCalendar::Ptr &calendar, const KCalendarCore::Incidence::Ptr &, const QDate &date);
+    void addIncidence(const Akonadi::ETMCalendar::Ptr &calendar, const Akonadi::Item &, const QDate &date);
     ListViewItem *getItemForIncidence(const Akonadi::Item &);
 
-    QTreeWidget *mTreeWidget;
-    ListViewItem *mActiveItem;
+    QTreeWidget *mTreeWidget = nullptr;
+    ListViewItem *mActiveItem = nullptr;
     QHash<Akonadi::Item::Id, Akonadi::Item> mItems;
     QHash<Akonadi::Item::Id, QDate> mDateList;
     QDate mStartDate;
@@ -147,12 +145,14 @@ public:
   This class provides the initialization of a ListViewItem for calendar
   components using the Incidence::Visitor.
 */
-class ListView::Private::ListItemVisitor : public KCalCore::Visitor
+class ListView::Private::ListItemVisitor : public KCalendarCore::Visitor
 {
 public:
-    ListItemVisitor(ListViewItem *item, QDate dt) : mItem(item), mStartDate(dt)
+    ListItemVisitor(ListViewItem *item, QDate dt) : mItem(item)
+        , mStartDate(dt)
     {
     }
+
     ~ListItemVisitor()
     {
     }
@@ -160,13 +160,14 @@ public:
     bool visit(const Event::Ptr &) override;
     bool visit(const Todo::Ptr &) override;
     bool visit(const Journal::Ptr &) override;
-    bool visit(const FreeBusy::Ptr &) override {
+    bool visit(const FreeBusy::Ptr &) override
+    {
         // to inhibit hidden virtual compile warning
         return true;
-    };
+    }
 
 private:
-    ListViewItem *mItem;
+    ListViewItem *mItem = nullptr;
     QDate mStartDate;
 };
 
@@ -183,24 +184,27 @@ bool ListView::Private::ListItemVisitor::visit(const Event::Ptr &e)
     mItem->setIcon(Summary_Column, eventPxmp);
 
     QDateTime next;
-    mItem->start = e->dtStart().toLocalZone().dateTime();
-    mItem->end = e->dtEnd().toLocalZone().dateTime();
+    mItem->start = e->dtStart().toLocalTime();
+    mItem->end = e->dtEnd().toLocalTime();
     if (e->recurs()) {
         const int duration = e->dtStart().secsTo(e->dtEnd());
-        KDateTime kdt(mStartDate, QTime(0,0,0));
+        QDateTime kdt(mStartDate, QTime(0, 0, 0));
         kdt = kdt.addSecs(-1);
-        mItem->start = e->recurrence()->getNextDateTime(kdt).toLocalZone().dateTime();
+        mItem->start = e->recurrence()->getNextDateTime(kdt).toLocalTime();
         mItem->end = mItem->start.addSecs(duration);
-        next = e->recurrence()->getNextDateTime(KDateTime(mItem->start)).toLocalZone().dateTime();
+        next = e->recurrence()->getNextDateTime(mItem->start).toLocalTime();
     }
 
     mItem->setText(Summary_Column, cleanSummary(e->summary(), next));
 
     if (e->allDay()) {
-        mItem->setText(StartDateTime_Column, QLocale().toString(mItem->start.date(), QLocale::ShortFormat));
-        mItem->setText(EndDateTime_Column, QLocale().toString(mItem->end.date(), QLocale::ShortFormat));
+        mItem->setText(StartDateTime_Column,
+                       QLocale().toString(mItem->start.date(), QLocale::ShortFormat));
+        mItem->setText(EndDateTime_Column,
+                       QLocale().toString(mItem->end.date(), QLocale::ShortFormat));
     } else {
-        mItem->setText(StartDateTime_Column, QLocale().toString(mItem->start, QLocale::ShortFormat));
+        mItem->setText(StartDateTime_Column,
+                       QLocale().toString(mItem->start, QLocale::ShortFormat));
         mItem->setText(EndDateTime_Column, QLocale().toString(mItem->end, QLocale::ShortFormat));
     }
 
@@ -216,19 +220,27 @@ bool ListView::Private::ListItemVisitor::visit(const Todo::Ptr &t)
     mItem->setText(Summary_Column, cleanSummary(t->summary(), QDateTime()));
 
     if (t->hasStartDate()) {
-        if (t->allDay())
-            mItem->setText(StartDateTime_Column, QLocale().toString(t->dtStart().toLocalZone().date(), QLocale::ShortFormat));
-        else
-            mItem->setText(StartDateTime_Column, QLocale().toString(t->dtStart().toLocalZone().dateTime(), QLocale::ShortFormat));
+        if (t->allDay()) {
+            mItem->setText(StartDateTime_Column,
+                           QLocale().toString(t->dtStart().toLocalTime().date(),
+                                              QLocale::ShortFormat));
+        } else {
+            mItem->setText(StartDateTime_Column,
+                           QLocale().toString(t->dtStart().toLocalTime(), QLocale::ShortFormat));
+        }
     } else {
         mItem->setText(StartDateTime_Column, QStringLiteral("---"));
     }
 
     if (t->hasDueDate()) {
-        if (t->allDay())
-            mItem->setText(EndDateTime_Column, QLocale().toString(t->dtDue().toLocalZone().date(), QLocale::ShortFormat));
-        else
-            mItem->setText(EndDateTime_Column, QLocale().toString(t->dtDue().toLocalZone().dateTime(), QLocale::ShortFormat));
+        if (t->allDay()) {
+            mItem->setText(EndDateTime_Column,
+                           QLocale().toString(t->dtDue().toLocalTime().date(),
+                                              QLocale::ShortFormat));
+        } else {
+            mItem->setText(EndDateTime_Column,
+                           QLocale().toString(t->dtDue().toLocalTime(), QLocale::ShortFormat));
+        }
     } else {
         mItem->setText(EndDateTime_Column, QStringLiteral("---"));
     }
@@ -248,17 +260,20 @@ bool ListView::Private::ListItemVisitor::visit(const Journal::Ptr &j)
     } else {
         mItem->setText(Summary_Column, cleanSummary(j->summary(), QDateTime()));
     }
-    if (j->allDay())
-        mItem->setText(StartDateTime_Column, QLocale().toString(j->dtStart().toLocalZone().date(), QLocale::ShortFormat));
-    else
-        mItem->setText(StartDateTime_Column, QLocale().toString(j->dtStart().toLocalZone().dateTime(), QLocale::ShortFormat));
+    if (j->allDay()) {
+        mItem->setText(StartDateTime_Column,
+                       QLocale().toString(j->dtStart().toLocalTime().date(), QLocale::ShortFormat));
+    } else {
+        mItem->setText(StartDateTime_Column,
+                       QLocale().toString(j->dtStart().toLocalTime(), QLocale::ShortFormat));
+    }
 
     return true;
 }
 
-ListView::ListView(const Akonadi::ETMCalendar::Ptr &calendar,
-                   QWidget *parent, bool nonInteractive)
-    : EventView(parent), d(new Private())
+ListView::ListView(const Akonadi::ETMCalendar::Ptr &calendar, QWidget *parent, bool nonInteractive)
+    : EventView(parent)
+    , d(new Private())
 {
     setCalendar(calendar);
     d->mActiveItem = nullptr;
@@ -278,13 +293,13 @@ ListView::ListView(const Akonadi::ETMCalendar::Ptr &calendar,
     d->mTreeWidget->setRootIsDecorated(false);
 
     QBoxLayout *layoutTop = new QVBoxLayout(this);
-    layoutTop->setMargin(0);
+    layoutTop->setContentsMargins(0, 0, 0, 0);
     layoutTop->addWidget(d->mTreeWidget);
 
-    QObject::connect(d->mTreeWidget, SIGNAL(doubleClicked(QModelIndex)),
-                     SLOT(defaultItemAction(QModelIndex)));
+    QObject::connect(d->mTreeWidget, QOverload<const QModelIndex &>::of(&QTreeWidget::doubleClicked), this,
+                     QOverload<const QModelIndex &>::of(&ListView::defaultItemAction));
     QObject::connect(d->mTreeWidget,
-                     &QWidget::customContextMenuRequested,
+                     &QTreeWidget::customContextMenuRequested,
                      this, &ListView::popupMenu);
     QObject::connect(d->mTreeWidget, &QTreeWidget::itemSelectionChanged,
                      this, &ListView::processSelectionChange);
@@ -309,8 +324,8 @@ int ListView::currentDateCount() const
 Akonadi::Item::List ListView::selectedIncidences() const
 {
     Akonadi::Item::List eventList;
-    QTreeWidgetItem *item = d->mTreeWidget->selectedItems().isEmpty() ? nullptr :
-                            d->mTreeWidget->selectedItems().first();
+    QTreeWidgetItem *item = d->mTreeWidget->selectedItems().isEmpty() ? nullptr
+                            : d->mTreeWidget->selectedItems().first();
     if (item) {
         ListViewItem *i = static_cast<ListViewItem *>(item);
         eventList.append(i->mIncidence);
@@ -370,27 +385,25 @@ void ListView::showAll()
 }
 
 void ListView::Private::addIncidences(const Akonadi::ETMCalendar::Ptr &calendar,
-                                      const KCalCore::Incidence::List &incidences,
+                                      const KCalendarCore::Incidence::List &incidences,
                                       const QDate &date)
 {
-    for (const KCalCore::Incidence::Ptr &incidence : incidences) {
+    for (const KCalendarCore::Incidence::Ptr &incidence : incidences) {
         addIncidence(calendar, incidence, date);
     }
 }
 
 void ListView::Private::addIncidence(const Akonadi::ETMCalendar::Ptr &calendar,
-                                     const Akonadi::Item &item,
-                                     const QDate &date)
+                                     const Akonadi::Item &item, const QDate &date)
 {
     Q_ASSERT(calendar);
-    if (item.isValid() && item.hasPayload<KCalCore::Incidence::Ptr>()) {
-        addIncidence(calendar, item.payload<KCalCore::Incidence::Ptr>(), date);
+    if (item.isValid() && item.hasPayload<KCalendarCore::Incidence::Ptr>()) {
+        addIncidence(calendar, item.payload<KCalendarCore::Incidence::Ptr>(), date);
     }
 }
 
 void ListView::Private::addIncidence(const Akonadi::ETMCalendar::Ptr &calendar,
-                                     const KCalCore::Incidence::Ptr &incidence,
-                                     const QDate &date)
+                                     const KCalendarCore::Incidence::Ptr &incidence, const QDate &date)
 {
     if (!incidence) {
         return;
@@ -406,8 +419,8 @@ void ListView::Private::addIncidence(const Akonadi::ETMCalendar::Ptr &calendar,
     mItems.insert(aitem.id(), aitem);
     Incidence::Ptr tinc = incidence;
 
-    if (tinc->customProperty("KABC", "BIRTHDAY") == QLatin1String("YES") ||
-            tinc->customProperty("KABC", "ANNIVERSARY") == QLatin1String("YES")) {
+    if (tinc->customProperty("KABC", "BIRTHDAY") == QLatin1String("YES")
+        || tinc->customProperty("KABC", "ANNIVERSARY") == QLatin1String("YES")) {
         const int years = EventViews::yearDiff(tinc->dtStart().date(), mEndDate);
         if (years > 0) {
             tinc = Incidence::Ptr(incidence->clone());
@@ -423,7 +436,8 @@ void ListView::Private::addIncidence(const Akonadi::ETMCalendar::Ptr &calendar,
     for (int col = 0; col < Dummy_EOF_Column; ++col) {
         item->setToolTip(col,
                          IncidenceFormatter::toolTipStr(
-                             CalendarSupport::displayName(calendar.data(), aitem.parentCollection()),
+                             CalendarSupport::displayName(calendar.data(),
+                                                          aitem.parentCollection()),
                              incidence));
     }
 
@@ -449,25 +463,24 @@ void ListView::showIncidences(const Akonadi::Item::List &itemList, const QDate &
 void ListView::changeIncidenceDisplay(const Akonadi::Item &aitem, int action)
 {
     const Incidence::Ptr incidence = CalendarSupport::incidence(aitem);
-    ListViewItem *item;
+    ListViewItem *item = nullptr;
     QDate f = d->mSelectedDates.first();
     QDate l = d->mSelectedDates.last();
 
     QDate date;
     if (CalendarSupport::hasTodo(aitem)) {
-        date = CalendarSupport::todo(aitem)->dtDue().toLocalZone().date();
+        date = CalendarSupport::todo(aitem)->dtDue().toLocalTime().date();
     } else {
-        date = incidence->dtStart().toLocalZone().date();
+        date = incidence->dtStart().toLocalTime().date();
     }
 
     switch (action) {
-    case Akonadi::IncidenceChanger::ChangeTypeCreate: {
+    case Akonadi::IncidenceChanger::ChangeTypeCreate:
         if (date >= f && date <= l) {
             d->addIncidence(calendar(), aitem, date);
         }
         break;
-    }
-    case Akonadi::IncidenceChanger::ChangeTypeModify: {
+    case Akonadi::IncidenceChanger::ChangeTypeModify:
         item = d->getItemForIncidence(aitem);
         if (item) {
             delete item;
@@ -478,12 +491,10 @@ void ListView::changeIncidenceDisplay(const Akonadi::Item &aitem, int action)
             d->addIncidence(calendar(), aitem, date);
         }
         break;
-    }
-    case Akonadi::IncidenceChanger::ChangeTypeDelete: {
+    case Akonadi::IncidenceChanger::ChangeTypeDelete:
         item = d->getItemForIncidence(aitem);
         delete item;
         break;
-    }
     default:
         qCDebug(CALENDARVIEW_LOG) << "Illegal action" << action;
     }
@@ -588,4 +599,3 @@ QSize ListView::sizeHint() const
     return QSize(s.width() + style()->pixelMetric(QStyle::PM_ScrollBarExtent) + 1,
                  s.height());
 }
-
