@@ -46,25 +46,18 @@ class TodoCompleteDelegate : public QStyledItemDelegate
 public:
     explicit TodoCompleteDelegate(QObject *parent = nullptr);
 
-    ~TodoCompleteDelegate();
+    ~TodoCompleteDelegate() override;
 
-    void paint(QPainter *painter, const QStyleOptionViewItem &option,
-               const QModelIndex &index) const override;
-    QSize sizeHint(const QStyleOptionViewItem &option,
-                   const QModelIndex &index) const override;
+    void paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const override;
+    QSize sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const override;
 
-    QWidget *createEditor(QWidget *parent, const QStyleOptionViewItem &option,
-                          const QModelIndex &index) const override;
+    QWidget *createEditor(QWidget *parent, const QStyleOptionViewItem &option, const QModelIndex &index) const override;
     void setEditorData(QWidget *editor, const QModelIndex &index) const override;
-    void setModelData(QWidget *editor, QAbstractItemModel *model,
-                      const QModelIndex &index) const override;
-    void updateEditorGeometry(QWidget *editor,
-                              const QStyleOptionViewItem &option,
-                              const QModelIndex &index) const override;
+    void setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const override;
+    void updateEditorGeometry(QWidget *editor, const QStyleOptionViewItem &option, const QModelIndex &index) const override;
 
 private:
-    void initStyleOptionProgressBar(QStyleOptionProgressBar *option,
-                                    const QModelIndex &index) const;
+    void initStyleOptionProgressBar(QStyleOptionProgressBar *option, const QModelIndex &index) const;
 };
 
 class TodoCompleteSlider : public QSlider
@@ -91,16 +84,12 @@ class TodoPriorityDelegate : public QStyledItemDelegate
 public:
     explicit TodoPriorityDelegate(QObject *parent = nullptr);
 
-    ~TodoPriorityDelegate();
+    ~TodoPriorityDelegate() override;
 
-    QWidget *createEditor(QWidget *parent, const QStyleOptionViewItem &option,
-                          const QModelIndex &index) const override;
+    QWidget *createEditor(QWidget *parent, const QStyleOptionViewItem &option, const QModelIndex &index) const override;
     void setEditorData(QWidget *editor, const QModelIndex &index) const override;
-    void setModelData(QWidget *editor, QAbstractItemModel *model,
-                      const QModelIndex &index) const override;
-    void updateEditorGeometry(QWidget *editor,
-                              const QStyleOptionViewItem &option,
-                              const QModelIndex &index) const override;
+    void setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const override;
+    void updateEditorGeometry(QWidget *editor, const QStyleOptionViewItem &option, const QModelIndex &index) const override;
 };
 
 /**
@@ -116,16 +105,12 @@ class TodoDueDateDelegate : public QStyledItemDelegate
 public:
     explicit TodoDueDateDelegate(QObject *parent = nullptr);
 
-    ~TodoDueDateDelegate();
+    ~TodoDueDateDelegate() override;
 
-    QWidget *createEditor(QWidget *parent, const QStyleOptionViewItem &option,
-                          const QModelIndex &index) const override;
+    QWidget *createEditor(QWidget *parent, const QStyleOptionViewItem &option, const QModelIndex &index) const override;
     void setEditorData(QWidget *editor, const QModelIndex &index) const override;
-    void setModelData(QWidget *editor, QAbstractItemModel *model,
-                      const QModelIndex &index) const override;
-    void updateEditorGeometry(QWidget *editor,
-                              const QStyleOptionViewItem &option,
-                              const QModelIndex &index) const override;
+    void setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const override;
+    void updateEditorGeometry(QWidget *editor, const QStyleOptionViewItem &option, const QModelIndex &index) const override;
 };
 
 /**
@@ -141,16 +126,12 @@ class TodoCategoriesDelegate : public QStyledItemDelegate
 public:
     explicit TodoCategoriesDelegate(QObject *parent = nullptr);
 
-    ~TodoCategoriesDelegate();
+    ~TodoCategoriesDelegate() override;
 
-    QWidget *createEditor(QWidget *parent, const QStyleOptionViewItem &option,
-                          const QModelIndex &index) const override;
+    QWidget *createEditor(QWidget *parent, const QStyleOptionViewItem &option, const QModelIndex &index) const override;
     void setEditorData(QWidget *editor, const QModelIndex &index) const override;
-    void setModelData(QWidget *editor, QAbstractItemModel *model,
-                      const QModelIndex &index) const override;
-    void updateEditorGeometry(QWidget *editor,
-                              const QStyleOptionViewItem &option,
-                              const QModelIndex &index) const override;
+    void setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const override;
+    void updateEditorGeometry(QWidget *editor, const QStyleOptionViewItem &option, const QModelIndex &index) const override;
 
     void setCalendar(const Akonadi::ETMCalendar::Ptr &cal);
 private:
@@ -169,14 +150,12 @@ class TodoRichTextDelegate : public QStyledItemDelegate
 public:
     explicit TodoRichTextDelegate(QObject *parent = nullptr);
 
-    ~TodoRichTextDelegate();
+    ~TodoRichTextDelegate() override;
 
-    void paint(QPainter *painter, const QStyleOptionViewItem &option,
-               const QModelIndex &index) const override;
-    QSize sizeHint(const QStyleOptionViewItem &option,
-                   const QModelIndex &index) const override;
+    void paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const override;
+    QSize sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const override;
 private:
-    QTextDocument *m_textDoc;
+    QTextDocument *m_textDoc = nullptr;
 };
 
 #endif
